Index: src/nettest_omni.c
===================================================================
--- src/nettest_omni.c	(revision 676)
+++ src/nettest_omni.c	(working copy)
@@ -46,6 +46,7 @@
 #if HAVE_SCHED_H
 # include <sched.h>
 #endif
+#include <poll.h>
 
 #include <fcntl.h>
 #ifndef WIN32
@@ -2990,6 +2991,10 @@
     fflush(where);
   }
 
+#ifdef RTT
+      gettimeofday(send_ring->buffer_ptr, 0);
+#endif
+
   if (destination) {
     if (have_pktinfo) {
       len = send_pktinfo(data_socket,
@@ -3030,6 +3035,25 @@
 #endif
     }
   }
+
+#ifdef RTT
+  struct pollfd fds = { .fd = data_socket, .events = POLLIN };
+  if (poll(&fds, 1, 0) > 0) {
+    struct timeval now;
+    struct timeval before;
+    if (recv(data_socket, &before, sizeof(struct timeval), MSG_WAITALL) == -1) {
+      if(errno != EINTR) {
+        perror("netperf: recv timeval");
+        exit(-1);
+      }
+    }
+    gettimeofday(&now, 0);
+    int rtt = delta_micro(&before, &now);
+    if (rtt > 0)
+      fprintf(stderr, "%d usec RTT\n", rtt);
+  }
+#endif
+
   if(len != bytes_to_send) {
     /* don't forget that some platforms may do a partial send upon
        receipt of the interrupt and not return an EINTR... */
@@ -5790,7 +5814,21 @@
 	}
 	bytes_received += ret;
 	local_receive_calls += temp_recvs;
+
+#ifdef RTT
+        int chunk = bytes_received % bytes_to_recv;
+        if (chunk && chunk < ret) {
+          struct timeval *before = &(recv_ring->buffer_ptr[ret - chunk]);
+          struct timeval now;
+          gettimeofday(&now, 0);
+          fprintf(stderr, "%d usec one-way delay \n", delta_micro(before, &now));
+          if(send(data_socket, before, sizeof(struct timeval), 0) == -1) {
+            perror("netperf: send timeval");
+            exit(-1);
       }
+        }
+#endif
+      }
       else if (ret == 0) {
 	/* is this the end of a test, just a zero-byte recv, or
 	   something else? that is an exceedingly good question and
